@@ -8,7 +8,7 @@ Usage::
     data: GetRawMessageContentResponseTypeDef = {...}
 """
 import sys
-from typing import IO, Union
+from typing import IO
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -19,5 +19,5 @@ else:
 __all__ = ("GetRawMessageContentResponseTypeDef",)
 
 GetRawMessageContentResponseTypeDef = TypedDict(
-    "GetRawMessageContentResponseTypeDef", {"messageContent": Union[bytes, IO]}
+    "GetRawMessageContentResponseTypeDef", {"messageContent": IO[bytes]}
 )
